==> ejc-metadata-api-3.0.0-20230104.084935-250-sources.jar: com/ejianc/foundation/metadata/vo/MdRelationQuoteVO.java <==
package com.ejianc.foundation.metadata.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 关系bean
 * 
 * @author liyongjia
 */
public class MdRelationQuoteVO extends BaseVO {

	private static final long serialVersionUID = 1L;
	
	private Long relationId;// 关系ID

	private Long sourceFieldId;// 来源字段ID

	private String sourceField;// 来源字段

	private String sourceFieldName;// 字段名称

	private Long targetFieldId;// 对应实体字段ID

	private String targetField;// 对应实体字段

	public Long getRelationId() {
		return relationId;
	}

	public void setRelationId(Long relationId) {
		this.relationId = relationId;
	}

	@ReferSerialTransfer(referCode="md-attribute")
	public Long getSourceFieldId() {
		return sourceFieldId;
	}

	@ReferDeserialTransfer
	public void setSourceFieldId(Long sourceFieldId) {
		this.sourceFieldId = sourceFieldId;
	}

	public String getSourceField() {
		return sourceField;
	}

	public void setSourceField(String sourceField) {
		this.sourceField = sourceField;
	}

	public String getSourceFieldName() {
		return sourceFieldName;
	}

	public void setSourceFieldName(String sourceFieldName) {
		this.sourceFieldName = sourceFieldName;
	}

	@ReferSerialTransfer(referCode="md-attribute")
	public Long getTargetFieldId() {
		return targetFieldId;
	}

	@ReferDeserialTransfer
	public void setTargetFieldId(Long targetFieldId) {
		this.targetFieldId = targetFieldId;
	}

	public String getTargetField() {
		return targetField;
	}

	public void setTargetField(String targetField) {
		this.targetField = targetField;
	}
}

==> ejc-metadata-api-3.0.0-20230208.021216-254-sources.jar: com/ejianc/foundation/metadata/vo/MdRelationQuoteVO.java <==
package com.ejianc.foundation.metadata.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 关系bean
 * 
 * @author liyongjia
 */
public class MdRelationQuoteVO extends BaseVO {

	private static final long serialVersionUID = 1L;
	
	private Long relationId;// 关系ID

	private Long sourceFieldId;// 来源字段ID

	private String sourceField;// 来源字段

	private String sourceFieldCode;// 来源字段--实体

	private String sourceFieldName;// 字段名称

	private Long targetFieldId;// 对应实体字段ID

	private String targetField;// 对应实体字段

	private String targetFieldCode;// 对应实体字段--实体

	public Long getRelationId() {
		return relationId;
	}

	public void setRelationId(Long relationId) {
		this.relationId = relationId;
	}

	@ReferSerialTransfer(referCode="md-attribute")
	public Long getSourceFieldId() {
		return sourceFieldId;
	}

	@ReferDeserialTransfer
	public void setSourceFieldId(Long sourceFieldId) {
		this.sourceFieldId = sourceFieldId;
	}

	public String getSourceField() {
		return sourceField;
	}

	public void setSourceField(String sourceField) {
		this.sourceField = sourceField;
	}

	public String getSourceFieldName() {
		return sourceFieldName;
	}

	public void setSourceFieldName(String sourceFieldName) {
		this.sourceFieldName = sourceFieldName;
	}

	@ReferSerialTransfer(referCode="md-attribute")
	public Long getTargetFieldId() {
		return targetFieldId;
	}

	@ReferDeserialTransfer
	public void setTargetFieldId(Long targetFieldId) {
		this.targetFieldId = targetFieldId;
	}

	public String getTargetField() {
		return targetField;
	}

	public void setTargetField(String targetField) {
		this.targetField = targetField;
	}

	public String getSourceFieldCode() {
		return sourceFieldCode;
	}

	public void setSourceFieldCode(String sourceFieldCode) {
		this.sourceFieldCode = sourceFieldCode;
	}

	public String getTargetFieldCode() {
		return targetFieldCode;
	}

	public void setTargetFieldCode(String targetFieldCode) {
		this.targetFieldCode = targetFieldCode;
	}
}
